Class: CobraCommander::Executor::IsolatedPTY
- Inherits:
-
TTY::Command
- Object
- TTY::Command
- CobraCommander::Executor::IsolatedPTY
- Defined in:
- lib/cobra_commander/executor/isolated_pty.rb
Overview
A PTY-enabled TTY::Command used to execute component scripts.
Per-execution environment variables are supplied to TTY::Command#run! (so they are scoped to each subprocess and never mutate the parent ENV), while environment isolation/enhancement such as Bundler’s ‘with_unbundled_env` is contributed by the package sources through their #around_command (see CobraCommander::Ruby::Bundle).
Instance Method Summary collapse
-
#initialize ⇒ IsolatedPTY
constructor
A new instance of IsolatedPTY.
Constructor Details
#initialize ⇒ IsolatedPTY
Returns a new instance of IsolatedPTY.
15 16 17 |
# File 'lib/cobra_commander/executor/isolated_pty.rb', line 15 def initialize(**) super(pty: true, **) end |